<?php
/**
 * The template for displaying Comments.
 *
 * The area of the page that contains both current comments
 * and the comment form. The actual display of comments is
 * handled by a callback to spd2017_comment() which is
 * located in the includes/template-tags.php file.
 *
 * @package spd2017
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() )
	return;
?>

	<div id="comments" class="comments-area">

	<?php // You can start editing here -- including this comment! ?>

	<?php if ( have_comments() ) : ?>
		<header class="page-header">
			<h2 class="comments-title">
				<?php
					printf( _nx( 'One thought on &ldquo;%2$s&rdquo;', '%1$s thoughts on &ldquo;%2$s&rdquo;', get_comments_number(), 'comments title', 'spd2017' ),
						number_format_i18n( get_comments_number() ), '<span>' . get_the_title() . '</span>' );
				?>
			</h2>
		</header>

		<ol class="comment-list media-list">
			<?php
				/* Loop through and list the comments. Tell wp_list_comments()
				 * to use spd2017_comment() to format the comments.
				 * If you want to overload this in a child theme then you can
				 * define spd2017_comment() and that will be used instead.
				 * See spd2017_comment() in includes/template-tags.php for more.
				 */
				wp_list_comments( array( 'callback' => 'spd2017_comment', 'avatar_size' => 50 ) );
			?>
		</ol><!-- .comment-list -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : // are there comments to navigate through ?>
		<nav id="comment-nav-below" class="comment-navigation" role="navigation">
			<h1 class="screen-reader-text"><?php _e( 'Comment navigation', 'spd2017' ); ?></h1>
			<ul class="pager">
				<li class="nav-previous"><?php previous_comments_link( '<i class="fa fa-angle-double-left"></i> '.__( 'Older Comments', 'spd2017' ) ); ?></li>
				<li class="nav-next"><?php next_comments_link( __( 'Newer Comments', 'spd2017' ).' <i class="fa fa-angle-double-right"></i>'); ?></li>
			</ul>
		</nav><!-- #comment-nav-below -->
		<?php endif; // check for comment navigation ?>

	<?php endif; // have_comments() ?>

	<?php
		// If comments are closed and there are comments, let's leave a little note, shall we?
		if ( ! comments_open() && '0' != get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
	?>
		<p class="no-comments"><?php _e( 'Comments are closed.', 'spd2017' ); ?></p>
	<?php endif; ?>

	<?php 
		// getting to skin the comment requires an hack ugly as butt - like traditionally always in wordpress
		$fields =  array(
			'author' =>
			'<div class="form-group">' .
			'<div class="col-sm-3"><label for="author">' . __( 'Name', 'spd2017' ) . '</label> <span class="required">*</span>'.'</div>'.
			'<div class="col-sm-9"><input id="author" name="author" type="text" class="form-control" value="' . esc_attr( $commenter['comment_author'] ). '"  aria-required="true"/></div>'.
			'</div>',

			'email' =>
			'<div class="form-group">' .
			'<div class="col-sm-3"><label for="email">' . __( 'Email', 'spd2017' ) . '</label> <span class="required">*</span>' .'</div>'.
			'<div class="col-sm-9"><input id="email" name="email" type="email" class="form-control" value="' . esc_attr( $commenter['comment_author_email'] ).'"  aria-required="true"/></div>'.
			'</div>',

			'url' =>
			'<div class="form-group">' .
			'<div class="col-sm-3"><label for="url">' . __( 'Website', 'spd2017' ) . '</label> ' .'</div>'.
			'<div class="col-sm-9"><input id="url" name="url" type="text" class="form-control" value="' . esc_attr( $commenter['comment_author_url'] ). '" /></div>'.
			'</div>',
			);
		ob_start();
		comment_form( $args = array(
			  'fields'            => $fields,
			  'id_form'           => 'commentform',  // that's the wordpress default value! delete it or edit it ;)
			  'id_submit'         => 'commentsubmit',
			  'title_reply'       => __( 'Leave a Reply', 'spd2017' ),  // that's the wordpress default value! delete it or edit it ;)
			  'title_reply_to'    => __( 'Leave a Reply to %s', 'spd2017' ),  // that's the wordpress default value! delete it or edit it ;)
			  'cancel_reply_link' => __( 'Cancel Reply', 'spd2017' ),  // that's the wordpress default value! delete it or edit it ;)
			  'label_submit'      => __( 'Post Comment', 'spd2017' ),  // that's the wordpress default value! delete it or edit it ;)
			
			  'comment_field' =>  '<div class="form-group"><div class="col-sm-12"><textarea id="comment" class="form-control" name="comment" cols="45" rows="8" aria-required="true"></textarea></div></div>',
			  'comment_notes_after' => ''
		)); 
		echo str_replace('class="comment-form"','class="form-horizontal"',ob_get_clean());
	
	?>

</div><!-- #comments -->
