<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="main">
 *
 * @package spd2017
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1.0">
<title><?php wp_title( '|', true, 'right' ); ?></title>
<link rel="profile" href="http://gmpg.org/xfn/11">
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
<link rel="shortcut icon" href="<?php echo get_stylesheet_directory_uri(); ?>/spd-favicon.ico"  type="image/x-icon">
<?php 
    // header stuff
    wp_head();
    
    // header image, we want a custom scaled image - without add_image_size() every picture to a one time used header format!
    $header_id = get_custom_header()->attachment_id;    
    if ( ! empty( $header_id ) ) {
        $header_full = wp_get_attachment_image_url($header_id, 'full');
?>
<style>    
    .site-header-inner { background-image: url(<?php echo aq_resize( $header_full, 480, 100, true ); ?>); }
    @media only screen and (min-width: 480px) {
        .site-header-inner { background-image: url(<?php echo aq_resize( $header_full, 768, 100, true ); ?>); }
    }
    @media only screen and (min-width: 768px) {
        .site-header-inner { background-image: url(<?php echo aq_resize( $header_full, 992, 200, true );; ?>); }
    }
    @media only screen and (min-width: 992px) {
        .site-header-inner { background-image: url(<?php echo aq_resize( $header_full, 1200, 200, true ); ?>); }
    }
    @media only screen and (min-width: 1200px) {
        .site-header-inner { background-image: url(<?php echo $header_full; ?>); }
    }    
</style>
<?php 
    }
?>
        
</head>

<body <?php body_class(); ?>>
<?php 
    do_action( 'before' );
    $blogname = get_bloginfo( 'name' );
?>

<nav class="site-navigation  navbar-fixed-desktop">		
	<div class="container">
		<div class="row">

				<div class="navbar navbar-spd" role="navigation">
					<div class="navbar-header">
						<button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-responsive-collapse">
							<span class="sr-only">Navigation</span>
							<span class="icon-bar"></span>
							<span class="icon-bar"></span>
							<span class="icon-bar"></span>
						</button>
                                            <div class="navbar-brand visible-xs"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php echo $blogname; ?></a></div>
					</div>

		<div class =" col-xs-12 col-sm-4 col-md-3 pull-right" style="padding: 0px;">
			<form class="navbar-form" role="search" action="<?php echo esc_url( home_url( '/' ) ); ?>">
				<div class="input-group">
					<input type="text" class="form-control" placeholder="<?php echo esc_attr_x( 'Search &hellip;', 'placeholder', 'spd2017' ); ?>" value="<?php echo esc_attr( get_search_query() ); ?>" name="s" title="<?php _ex( 'Search for:', 'label', 'spd2017' ); ?>">
					<div class="input-group-btn">
						<button type="submit" class="btn btn-navsearch" value="<?php echo esc_attr_x( 'Search', 'submit button', 'spd2017' ); ?>"><span class="glyphicon glyphicon-search"></span></button>
					</div>
				</div>
			</form>
		</div>

		    <!-- The WordPress Menu goes here -->
		<div class="col-xs-12 col-sm-8 col-md-9" style="padding-left: 0px;">
	        <?php wp_nav_menu(
                array(
                    'theme_location' => 'primary',
                    'container_class' => 'collapse navbar-collapse navbar-responsive-collapse',
                    'menu_class' => 'nav navbar-nav',
                    'fallback_cb' => '',
                    'menu_id' => 'main-menu',
                    'walker' => new wp_bootstrap_navwalker() ) ); ?>
		</div>
<div class="clearfix"></div>


				
			</div><!-- .navbar -->
		</div><!-- .row -->
	</div><!-- .container -->
</nav><!-- .site-navigation -->
    
    
<header id="masthead" class="site-header" role="banner">
	<div class="container-fluid site-header-inner">
		<div class="row">
                        <div class="container">
<?php 
	if ( ! empty( $blogname ) ){ ?>
				<div class="site-header-title hidden-xs">
					<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php echo $blogname; ?></a></h1>
					<h2 class="site-description"><?php bloginfo( 'description' ); ?></h2>
				</div>	
<?php }
?>
<?php 
	$logo_image = get_theme_mod( 'spd2017_options_logo');
	if ( ! empty( $logo_image ) ) { ?>
	<div id="logo" class="text-center <?php echo (get_theme_mod('spd2017_options_logo_justify')=='logo-center')?'col-xs-12':'col-xs-12 col-sm-offset-8 col-sm-4 col-md-offset-9 col-md-3' ?>"><img src="<?php echo $logo_image ?>"></div>
<?php }
?>
			</div>
		</div>
	</div><!-- .container -->
</header><!-- #masthead -->
		
<div class="main-content">	
	<div class="container">
		<div class="row">
			<div id="content" class="main-content-inner col-xs-12 col-sm-8 col-md-9 equalize">

